@@ -20,4 +20,4 @@ __author__ = "Moritz E. Beber"
 __email__ = "midnighter@posteo.net"
 
 
-from .info import *
+from .application.compatibility import print_dependencies, show_versions
